==> citrus-mail-4.0.0-sources.jar: org/citrusframework/model/config/mail/MailServerModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.mail;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="auth-required" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="auto-start" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="auto-accept" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="split-multipart" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="mail-properties" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="known-users" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="marshaller" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="debug-logging" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "server")
public class MailServerModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "port")
    protected String port;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "endpoint-adapter")
    protected String endpointAdapter;
    @XmlAttribute(name = "auth-required")
    protected Boolean authRequired;
    @XmlAttribute(name = "auto-start")
    protected Boolean autoStart;
    @XmlAttribute(name = "auto-accept")
    protected Boolean autoAccept;
    @XmlAttribute(name = "split-multipart")
    protected Boolean splitMultipart;
    @XmlAttribute(name = "mail-properties")
    protected String mailProperties;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "known-users")
    protected String knownUsers;
    @XmlAttribute(name = "marshaller")
    protected String marshaller;
    @XmlAttribute(name = "debug-logging")
    protected Boolean debugLogging;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der port-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der endpointAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointAdapter() {
        return endpointAdapter;
    }

    /**
     * Legt den Wert der endpointAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointAdapter(String value) {
        this.endpointAdapter = value;
    }

    /**
     * Ruft den Wert der authRequired-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAuthRequired() {
        return authRequired;
    }

    /**
     * Legt den Wert der authRequired-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuthRequired(Boolean value) {
        this.authRequired = value;
    }

    /**
     * Ruft den Wert der autoStart-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoStart() {
        return autoStart;
    }

    /**
     * Legt den Wert der autoStart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoStart(Boolean value) {
        this.autoStart = value;
    }

    /**
     * Ruft den Wert der autoAccept-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoAccept() {
        return autoAccept;
    }

    /**
     * Legt den Wert der autoAccept-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoAccept(Boolean value) {
        this.autoAccept = value;
    }

    /**
     * Ruft den Wert der splitMultipart-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isSplitMultipart() {
        return splitMultipart;
    }

    /**
     * Legt den Wert der splitMultipart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSplitMultipart(Boolean value) {
        this.splitMultipart = value;
    }

    /**
     * Ruft den Wert der mailProperties-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMailProperties() {
        return mailProperties;
    }

    /**
     * Legt den Wert der mailProperties-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMailProperties(String value) {
        this.mailProperties = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der knownUsers-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKnownUsers() {
        return knownUsers;
    }

    /**
     * Legt den Wert der knownUsers-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKnownUsers(String value) {
        this.knownUsers = value;
    }

    /**
     * Ruft den Wert der marshaller-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMarshaller() {
        return marshaller;
    }

    /**
     * Legt den Wert der marshaller-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMarshaller(String value) {
        this.marshaller = value;
    }

    /**
     * Ruft den Wert der debugLogging-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDebugLogging() {
        return debugLogging;
    }

    /**
     * Legt den Wert der debugLogging-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDebugLogging(Boolean value) {
        this.debugLogging = value;
    }

}

==> citrus-mail-4.3.3-sources.jar: org/citrusframework/model/config/mail/MailServerModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.5 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.config.mail;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlID;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <attribute name="id" use="required" type="{http://www.w3.org/2001/XMLSchema}ID" />
 *       <attribute name="port" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="endpoint-adapter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="auth-required" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="auto-start" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="auto-accept" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="split-multipart" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *       <attribute name="mail-properties" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="message-converter" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="known-users" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="marshaller" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="debug-logging" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "server")
public class MailServerModel {

    @XmlAttribute(name = "id", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "port")
    protected String port;
    @XmlAttribute(name = "timeout")
    protected String timeout;
    @XmlAttribute(name = "endpoint-adapter")
    protected String endpointAdapter;
    @XmlAttribute(name = "auth-required")
    protected Boolean authRequired;
    @XmlAttribute(name = "auto-start")
    protected Boolean autoStart;
    @XmlAttribute(name = "auto-accept")
    protected Boolean autoAccept;
    @XmlAttribute(name = "split-multipart")
    protected Boolean splitMultipart;
    @XmlAttribute(name = "mail-properties")
    protected String mailProperties;
    @XmlAttribute(name = "message-converter")
    protected String messageConverter;
    @XmlAttribute(name = "known-users")
    protected String knownUsers;
    @XmlAttribute(name = "marshaller")
    protected String marshaller;
    @XmlAttribute(name = "debug-logging")
    protected Boolean debugLogging;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der port-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPort() {
        return port;
    }

    /**
     * Legt den Wert der port-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPort(String value) {
        this.port = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

    /**
     * Ruft den Wert der endpointAdapter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEndpointAdapter() {
        return endpointAdapter;
    }

    /**
     * Legt den Wert der endpointAdapter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEndpointAdapter(String value) {
        this.endpointAdapter = value;
    }

    /**
     * Ruft den Wert der authRequired-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAuthRequired() {
        return authRequired;
    }

    /**
     * Legt den Wert der authRequired-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAuthRequired(Boolean value) {
        this.authRequired = value;
    }

    /**
     * Ruft den Wert der autoStart-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoStart() {
        return autoStart;
    }

    /**
     * Legt den Wert der autoStart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoStart(Boolean value) {
        this.autoStart = value;
    }

    /**
     * Ruft den Wert der autoAccept-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isAutoAccept() {
        return autoAccept;
    }

    /**
     * Legt den Wert der autoAccept-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAutoAccept(Boolean value) {
        this.autoAccept = value;
    }

    /**
     * Ruft den Wert der splitMultipart-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isSplitMultipart() {
        return splitMultipart;
    }

    /**
     * Legt den Wert der splitMultipart-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setSplitMultipart(Boolean value) {
        this.splitMultipart = value;
    }

    /**
     * Ruft den Wert der mailProperties-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMailProperties() {
        return mailProperties;
    }

    /**
     * Legt den Wert der mailProperties-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMailProperties(String value) {
        this.mailProperties = value;
    }

    /**
     * Ruft den Wert der messageConverter-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageConverter() {
        return messageConverter;
    }

    /**
     * Legt den Wert der messageConverter-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageConverter(String value) {
        this.messageConverter = value;
    }

    /**
     * Ruft den Wert der knownUsers-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getKnownUsers() {
        return knownUsers;
    }

    /**
     * Legt den Wert der knownUsers-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setKnownUsers(String value) {
        this.knownUsers = value;
    }

    /**
     * Ruft den Wert der marshaller-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMarshaller() {
        return marshaller;
    }

    /**
     * Legt den Wert der marshaller-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMarshaller(String value) {
        this.marshaller = value;
    }

    /**
     * Ruft den Wert der debugLogging-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isDebugLogging() {
        return debugLogging;
    }

    /**
     * Legt den Wert der debugLogging-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDebugLogging(Boolean value) {
        this.debugLogging = value;
    }

}
